package net.sf.javaprinciples.core;

import java.security.Principal;
import java.util.UUID;

/**
 * Utility methods for managing thread/request based attributes.
 *
 * a. RequestContext - A unique identifier for a specific request
 * b. Principal - The principal associated with the request
 *
 * @author Warwick Slade
 */
public class RequestContext
{
    private static final String CORRELATION = "X-Correlation";
    private static final ThreadLocal<Principal> INSTANCE = new ThreadLocal<Principal>();

    public static void putCorrelation(String correlation)
    {
        org.slf4j.MDC.put(CORRELATION, correlation);
    }

    public static void putCorrelation()
    {
        org.slf4j.MDC.put(CORRELATION, UUID.randomUUID().toString());
    }

    public static void resetCorrelation()
    {
        org.slf4j.MDC.remove(CORRELATION);
    }

    public static String getCorrelation()
    {
        return org.slf4j.MDC.get(CORRELATION);
    }

    public static void putPrincipal(Principal principal)
    {
        INSTANCE.set(principal);
    }

    public static Principal getPrincipal()
    {
        return INSTANCE.get();
    }

    public static void resetPrincipal()
    {
        INSTANCE.remove();
    }

    private RequestContext()
    {
    }
}
